==> haskell-libxml-sax-0.7.5-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libxml-sax.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libxml-sax
version:              0.7.5
visibility:           public
id:                   libxml-sax-0.7.5-B8vBR4r6Cf24m3mbQjAuPi
key:                  libxml-sax-0.7.5-B8vBR4r6Cf24m3mbQjAuPi
license:              MIT
maintainer:           jmillikin@gmail.com
author:               John Millikin
stability:            experimental
homepage:             https://john-millikin.com/software/haskell-libxml/
synopsis:             Bindings for the libXML2 SAX interface
category:             Foreign, Text, XML, Parsing
abi:                  34df86d62313156e3907ca29817a10ee
exposed:              True
exposed-modules:      Text.XML.LibXML.SAX
import-dirs:          /usr/lib/ghc-8.10.1/site-local/libxml-sax-0.7.5
library-dirs:         /usr/lib/ghc-8.10.1/site-local/libxml-sax-0.7.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/libxml-sax-0.7.5
hs-libraries:         HSlibxml-sax-0.7.5-B8vBR4r6Cf24m3mbQjAuPi
extra-libraries:      xml2 xml2
include-dirs:         /usr/include/libxml2
depends:
    base-4.14.0.0 bytestring-0.10.10.0 text-1.2.3.2
    xml-types-0.3.6-72Xi3JmeGqF5UbvBPlmemw

haddock-interfaces:   /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
haddock-html:         /usr/share/doc/haskell-libxml-sax/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libxml-sax-0.7.5-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libxml-sax.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libxml-sax
version:              0.7.5
visibility:           public
id:                   libxml-sax-0.7.5-AlLEPHJUG9wEQksLBkpcAI
key:                  libxml-sax-0.7.5-AlLEPHJUG9wEQksLBkpcAI
license:              MIT
maintainer:           jmillikin@gmail.com
author:               John Millikin
stability:            experimental
homepage:             https://john-millikin.com/software/haskell-libxml/
synopsis:             Bindings for the libXML2 SAX interface
category:             Foreign, Text, XML, Parsing
abi:                  659afd0bc801fa1a87fae20faefb61ec
exposed:              True
exposed-modules:      Text.XML.LibXML.SAX
import-dirs:          /usr/lib/ghc-8.10.1/site-local/libxml-sax-0.7.5
library-dirs:         /usr/lib/ghc-8.10.1/site-local/libxml-sax-0.7.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/libxml-sax-0.7.5
hs-libraries:         HSlibxml-sax-0.7.5-AlLEPHJUG9wEQksLBkpcAI
extra-libraries:      xml2 xml2
include-dirs:         /usr/include/libxml2
depends:
    base-4.14.0.0 bytestring-0.10.10.0 text-1.2.3.2
    xml-types-0.3.7-9pMDZR0cCkmEphxRmWJVI7

haddock-interfaces:   /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
haddock-html:         /usr/share/doc/haskell-libxml-sax/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
